use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API
Alex
AnnoCPAN
Arthur
Axel
Cawley
Colin
Dave
David
Horner
Hu
Jenkins
Kulbiy
Newell
Nick
Piers
Schmidt
Steinbrunner
Sven
Willenbuecher
auth
colin
fREW
https
lib
